.. rst-class:: detail

GetFrame
===================

.. currentmodule:: compas_rrc

.. autoclass:: GetFrame

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~GetFrame.__init__
        ~GetFrame.from_msg
        ~GetFrame.parse_feedback
    
    